diff libpurple/protocols/msn/error.c @ 15823:32c366eeeb99

sed -ie 's/gaim/purple/g'
author Sean Egan <seanegan@gmail.com>
date Mon, 19 Mar 2007 07:01:17 +0000
parents acf21858f5e2
children 44b4e8bd759b
line wrap: on
line diff
--- a/libpurple/protocols/msn/error.c	Mon Mar 19 06:11:46 2007 +0000
+++ b/libpurple/protocols/msn/error.c	Mon Mar 19 07:01:17 2007 +0000
@@ -1,9 +1,9 @@
 /**
  * @file error.c Error functions
  *
- * gaim
+ * purple
  *
  * Gaim is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
  *
@@ -263,7 +263,7 @@
 	g_snprintf(buf, sizeof(buf), _("MSN Error: %s\n"),
 			   msn_error_get_text(type, &debug));
 	if (debug)
-		gaim_debug_warning("msn", "error %d: %s\n", type, buf);
+		purple_debug_warning("msn", "error %d: %s\n", type, buf);
 	else
-		gaim_notify_error(session->account->gc, NULL, buf, NULL);
+		purple_notify_error(session->account->gc, NULL, buf, NULL);
 }
@@ -1,9 +1,9 @@
  *
- * Gaim is the legal property of its developers, whose names are too numerous
+ * Purple is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.